@@ -680,9 +680,9 @@ class Tool:
         if isinstance(datas, list):
             L.acquire()
             try:
-                if not self.connection:
-                    self.connection = self.get_con()
-                cursor = self.connection.cursor()
+                if not self.conn:
+                    self.conn = self.get_con()
+                cursor = self.conn.cursor()
                 for data in datas:
                     key, value = analysis_dict(data, type="install")
                     kv_up = analysis_dict(data, type="update")
@@ -691,7 +691,7 @@ class Tool:
                         cursor.execute(sql)
                     except Exception as e:
                         print(e, sql)
-                self.connection.commit()
+                self.conn.commit()
                 cursor.close()
             finally:
                 L.release()
